@@ -29,8 +29,8 @@ if (two.tailed)
 {
 T <- t*m;
 IFt <- 1 + ((CV^2)*(le^2 + lc^2)*T)/(le + lc);
-r$n <- (IFt*(qnorm(1 - alpha/2) + qnorm(power))^2*(le + lc))/(T*(le - lc)^2);
-
+r$n <- ( (qnorm(1 - alpha/2) + qnorm(power))^2*(le + lc))/(T*(le - lc)^2);
+r$n <- IFt*r$n;
 #Perform iterative sample size, using the T statistic for small n.
 
 if (r$n < 30)
@@ -40,7 +40,8 @@ while (abs(r$n - nTemp) > 1)
 {
 nTemp <- r$n;
 IFt <- 1 + ((CV^2)*(le^2 + lc^2)*T)/(le + lc);
-r$n <- (IFt*( qt( (1 - alpha/2), df=( 2*(nTemp - 1)) + qt(power, df=(2*(nTemp - 1))))^2*(le + lc))/(T*(le - lc)^2));
+r$n <- ( ( qt( (1 - alpha/2), df=( 2*(nTemp - 1))) + qt(power, df=(2*(nTemp - 1))) )^2*(le + lc))/(T*(le - lc)^2);
+r$n <- IFt*r$n;
 }
 
 }
@@ -50,7 +51,8 @@ r$n <- (IFt*( qt( (1 - alpha/2), df=( 2*(nTemp - 1)) + qt(power, df=(2*(nTemp -
 if (!two.tailed)
 {
 IFt <- 1 + ((CV^2)*(le^2 + lc^2)*T)/(le + lc);
-r$n <- (IFt*( qt( (1 - alpha), df=( 2*(nTemp - 1)) + qt(power, df=(2*(nTemp - 1))))^2*(le + lc))/(T*(le - lc)^2));
+r$n <- ( (qnorm(1 - alpha) + qnorm(power))^2*(le + lc))/(T*(le - lc)^2);
+r$n <- IFt*r$n;
 
 if (r$n < 30)
 {
@@ -60,7 +62,8 @@ while (abs(r$n - nTemp) > 1)
 {
 nTemp <- r$n;
 IFt <- 1 + ((CV^2)*(le^2 + lc^2)*T)/(le + lc);
-r$n <- (IFt*( qt( (1 - alpha), df=( 2*(nTemp - 1)) + qt(power, df=(2*(nTemp - 1))))^2*(le + lc))/(T*(le - lc)^2));
+r$n <- ( ( qt( (1 - alpha), df=( 2*(nTemp - 1))) + qt(power, df=(2*(nTemp - 1))) )^2*(le + lc))/(T*(le - lc)^2);
+r$n <- IFt*r$n;
 }
 
 }
